@@ -26,7 +26,7 @@ parser.add_argument('-Pr', "--python_requires",
 parser.add_argument('-i', "--install_requires",
                     help="install_requires")
 parser.add_argument('-f', '--file', type=str, help='createPackge file')
-parser.add_argument('-n', '--new', type=tuple, help='newElement')
+parser.add_argument('-N', '--new', type=tuple, help='newElement')
 parser.add_argument('-e', '--entry_points', type=dict, help='entry_points')
 args = parser.parse_args()
 if args.file:
