@@ -160,7 +160,7 @@ setuptools.setup(
         self.createFile('./'+d+'/'+d, f'{n}.py', '# your python file')
         print(f'INFO[006] create the {n}.py file')
         print(f'{n} is success')
-        print('''Pleace use:
+        print(f'''Pleace use:
               cd {n}
               python setup.py sdist''')
 
@@ -177,7 +177,6 @@ setuptools.setup(
                     inp = input(
                         '文件已存在，是否删除？\nThe file already exists. Do you want to delete it? (y/N) ')
                     if inp == 'y':
-                        s
                         shutil.rmtree(name[2:])
                         break
                     elif inp == 'N':
